% Uniaxial MATLAB Code with DOF Loads
% Units: Pounds (lbs) and Inches (in)

clc     %Clear the window
clear   %Clear the memory

% This general format works well for most engineering problems
format short g

% Define the number of element dofs (always 2 for the uniaxial element)
NEdof=2;

% Define the number of structural dofs

% Initialize [S]
S=zeros(NSdof,NSdof);
E=30e6;
P=[-48;144] % The semicolon is a separator between rows in the vector

% Define the code numbers
CodeNum=[
3 1
1 2
2 4] % Here we write out each row explicitly

% Define geometry and loading for each member create the member stiffness
% and then assemble [S]. Note that no units are shown, you just need to be
% be consistent.

MemNum=1;
A=0.25;
L=4*12;
[k1]=Create_K(E,A,L)
[S]=Assemble_S(S,k1,MemNum,NEdof,NSdof,CodeNum);

MemNum=2;
A=0.5;
L=3*12;
[k2]=Create_K(E,A,L)
[S]=Assemble_S(S,k2,MemNum,NEdof,NSdof,CodeNum);

MemNum=3;
A=0.15;
L=2*12;
[k3]=Create_K(E,A,L)
[S]=Assemble_S(S,k3,MemNum,NEdof,NSdof,CodeNum);


%***************** SOLVE *****************

% Solve for displacements (note the use of the backslash operator instead
% of the inv command. We could have used d=inv(S)*(P), or even
% d=S^-1*(P), but the backslash approach is much more efficient.)
d=S\(P)


%************** POST-PROCESS *************

% Use compatibility to create the {u} vectors for each element
u1=[0; d(1)];
u2=[d(1); d(2)];
u3=[d(2); 0];

% Calculate the member end forces
Q1=k1*u1
Q2=k2*u2
Q3=k3*u3

% Calculate the support reactions
R3=Q1(1)
R4=Q3(2)        % Index(i) selects corresponding member end force 1,2 

